<?php

namespace ElementPack\Modules\RevealEffects;

use Elementor\Controls_Manager;
use ElementPack\Base\Element_Pack_Module_Base;

if (!defined('ABSPATH')) {
	exit;
} // Exit if accessed directly

class Module extends Element_Pack_Module_Base {

	public function __construct() {
		parent::__construct();
		$this->add_actions();
	}

	public function get_name() {
		return 'bdt-reveal-effects';
	}

	public function register_section($element) {
		$element->start_controls_section(
			'section_element_pack_reveal_controls',
			[
				'tab'   => Controls_Manager::TAB_ADVANCED,
				'label' => BDTEP_CP . esc_html__('Reveal Effects', 'bdthemes-element-pack') . BDTEP_NC,
			]
		);
		$element->end_controls_section();
	}


	public function register_controls($widget, $args) {

		$widget->add_control(
			'element_pack_reveal_effects_enable',
			[
				'label'              => esc_html__('Use Reveal Effects?', 'bdthemes-element-pack'),
				'type'               => Controls_Manager::SWITCHER,
				'render_type'        => 'none',
				'frontend_available' => true,
				'prefix_class'       => 'bdt-reveal-effects-',
			]
		);
		$widget->add_control(
			'element_pack_reveal_effects_direction',
			[
				'label'      => __('Direction', 'bdthemes-element-pack'),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'c',
				'options' => [
					'c' => __('Center', 'bdthemes-element-pack'),
					'lr' => __('Left to Right', 'bdthemes-element-pack'),
					'rl' => __('Right to Left', 'bdthemes-element-pack'),
					'tb' => __('Top to Bottom', 'bdthemes-element-pack'),
					'bt' => __('Bottom to top', 'bdthemes-element-pack')
				],
				'frontend_available' => true,
				'render_type' => 'template',
				'condition' => [
					'element_pack_reveal_effects_enable' => 'yes'
				]
			]
		);
		$widget->add_control(
			'element_pack_reveal_effects_easing',
			[
				'label'      => __('Easing', 'bdthemes-element-pack'),
				'type'       => Controls_Manager::SELECT,
				'default'    => 'easeInOutQuint',
				'render_type' => 'template',
				'options' => [
					'easeInQuad' => esc_html__('easeInQuad', 'bdthemes-element-pack'),
					'easeInCubic' => esc_html__('easeInCubic', 'bdthemes-element-pack'),
					'easeInQuart' => esc_html__('easeInQuart', 'bdthemes-element-pack'),
					'easeInQuint' => esc_html__('easeInQuint', 'bdthemes-element-pack'),
					'easeInSine' => esc_html__('easeInSine', 'bdthemes-element-pack'),
					'easeInExpo' => esc_html__('easeInExpo', 'bdthemes-element-pack'),
					'easeInCirc' => esc_html__('easeInCirc', 'bdthemes-element-pack'),
					'easeInBack' => esc_html__('easeInBack', 'bdthemes-element-pack'),
					'easeOutQuad' => esc_html__('easeOutQuad', 'bdthemes-element-pack'),
					'easeOutCubic' => esc_html__('easeOutCubic', 'bdthemes-element-pack'),
					'easeOutQuart' => esc_html__('easeOutQuart', 'bdthemes-element-pack'),
					'easeOutQuint' => esc_html__('easeOutQuint', 'bdthemes-element-pack'),
					'easeOutSine' => esc_html__('easeOutSine', 'bdthemes-element-pack'),
					'easeOutExpo' => esc_html__('easeOutExpo', 'bdthemes-element-pack'),
					'easeOutCirc' => esc_html__('easeOutCirc', 'bdthemes-element-pack'),
					'easeOutBack' => esc_html__('easeOutBack', 'bdthemes-element-pack'),
					'easeInBounce' => esc_html__('easeInBounce', 'bdthemes-element-pack'),
					'easeInOutQuad' => esc_html__('easeInOutQuad', 'bdthemes-element-pack'),
					'easeInOutCubic' => esc_html__('easeInOutCubic', 'bdthemes-element-pack'),
					'easeInOutQuart' => esc_html__('easeInOutQuart', 'bdthemes-element-pack'),
					'easeInOutQuint' => esc_html__('easeInOutQuint', 'bdthemes-element-pack'),
					'easeInOutSine' => esc_html__('easeInOutSine', 'bdthemes-element-pack'),
					'easeInOutExpo' => esc_html__('easeInOutExpo', 'bdthemes-element-pack'),
					'easeInOutCirc' => esc_html__('easeInOutCirc', 'bdthemes-element-pack'),
					'easeInOutBack' => esc_html__('easeInOutBack', 'bdthemes-element-pack'),
					'easeInOutBounce' => esc_html__('easeInOutBounce', 'bdthemes-element-pack'),
					'easeOutBounce' => esc_html__('easeOutBounce', 'bdthemes-element-pack'),
					'easeOutInQuad' => esc_html__('easeOutInQuad', 'bdthemes-element-pack'),
					'easeOutInCubic' => esc_html__('easeOutInCubic', 'bdthemes-element-pack'),
					'easeOutInQuart' => esc_html__('easeOutInQuart', 'bdthemes-element-pack'),
					'easeOutInQuint' => esc_html__('easeOutInQuint', 'bdthemes-element-pack'),
					'easeOutInSine' => esc_html__('easeOutInSine', 'bdthemes-element-pack'),
					'easeOutInExpo' => esc_html__('easeOutInExpo', 'bdthemes-element-pack'),
					'easeOutInCirc' => esc_html__('easeOutInCirc', 'bdthemes-element-pack'),
					'easeOutInBack' => esc_html__('easeOutInBack', 'bdthemes-element-pack'),
					'easeOutInBounce' => esc_html__('easeOutInBounce', 'bdthemes-element-pack'),
				],
				'frontend_available' => true,
				'condition' => [
					'element_pack_reveal_effects_enable' => 'yes'
				]
			]
		);
		$widget->add_control(
			'element_pack_reveal_effects_speed',
			[
				'label'         => __('Speed', 'bdthemes-element-pack'),
				'type'          => Controls_Manager::SLIDER,
				'size_units'    => ['px'],
				'range'         => [
					'px'        => [
						'min'   => 0,
						'max'   => 10,
						'step'  => 0.1,
					],

				],
				'default'       => [
					'unit'      => 'px',
					'size'      => 5,
				],
				'frontend_available' => true,
				'render_type' => 'template',
				'condition' => [
					'element_pack_reveal_effects_enable' => 'yes'
				]
			]
		);
		// $widget->add_control(
		// 	'element_pack_reveal_effects_delay',
		// 	[
		// 		'label'         => __('Delay', 'bdthemes-element-pack'),
		// 		'type'          => Controls_Manager::SLIDER,
		// 		'size_units'    => ['px'],
		// 		'range'         => [
		// 			'px'        => [
		// 				'min'   => 0,
		// 				'max'   => 20,
		// 				'step'  => 0.1,
		// 			]
		// 		],
		// 		'default'       => [
		// 			'size'      => 0,
		// 		],
		// 		'frontend_available' => true,
		// 		'render_type' => 'template',
		// 		'condition' => [
		// 			'element_pack_reveal_effects_enable' => 'yes'
		// 		]
		// 	]
		// );
		$widget->add_control(
			'element_pack_reveal_effects_color',
			[
				'label'     => __('Background', 'bdthemes-element-pack'),
				'type'      => Controls_Manager::COLOR,
				'frontend_available' => true,
				'render_type' => 'template',
				'condition' => [
					'element_pack_reveal_effects_enable' => 'yes'
				]
			]
		);
		// $widget->add_control(
		// 	'element_pack_reveal_effects_repeat',
		// 	[
		// 		'label'              => esc_html__('Repeat?', 'bdthemes-element-pack'),
		// 		'type'               => Controls_Manager::SWITCHER,
		// 		'render_type'        => 'none',
		// 		'frontend_available' => true,
		// 	]
		// );
	}



	public function enqueue_scripts() {
		wp_enqueue_script('anime', BDTEP_ASSETS_URL . 'vendor/js/anime.min.js', '3.2.1', true);
		wp_enqueue_script('revealFx', BDTEP_ASSETS_URL . 'vendor/js/RevealFx.js', '0.0.2', true);
	}
	public function should_script_enqueue($widget) {
		if ('yes' === $widget->get_settings_for_display('element_pack_reveal_effects_enable')) {
			$this->enqueue_scripts();
			wp_enqueue_style('ep-reveal-effects');
			wp_enqueue_script('ep-reveal-effects');
		}
	}

	protected function add_actions() {
		add_action('elementor/frontend/widget/before_render', [$this, 'should_script_enqueue']);
		add_action('elementor/preview/enqueue_scripts', [$this, 'enqueue_scripts']);
		add_action('elementor/element/common/_section_style/after_section_end', [$this, 'register_section']);
		add_action('elementor/element/common/section_element_pack_reveal_controls/before_section_end', [$this, 'register_controls'], 10, 2);
	}
}
